==========
Quickstart
==========

After :doc:`installation`, you can use ``django-bootstrap-v5`` in your templates.:

Load the ``bootstrap5`` library and use the ``bootstrap_*`` tags:


Example template
----------------

.. include:: example_template.rst


Template tags and filters
-------------------------

Refer to :doc:`templatetags` for more information.


Settings
--------

You can set defaults for ``django-bootstrap-v5`` in your settings file. Refer to :doc:`settings` for more information.


Demo application
----------------

The demo application provides a number of useful examples.

https://github.com/zelenij/django-bootstrap-v5/tree/main/example

